        function getT(rr,cc){
       if(rr==2 && cc==0){return '<strong>Temperatura (C) y Altura Geopotencial (m) en 500 hPa</strong><br><br><strong>20260619 a 12</strong> UTC HH+096 (rango:084-108)<br><strong>control +<br>EPS</strong>';}
       if(rr==2 && cc==1){return '<strong>Temperatura (C) y Altura Geopotencial (m) en 500 hPa</strong><br><br><strong>20260619 a 12</strong> UTC HH+096 (rango:084-108)<br>grupo: <strong>1</strong> representante: <strong>18</strong> miembros: 26 <strong>control</strong><br>0,2,7,9,14,15,18,20,22,24,25,27,28,32,33,34,36,37,38,39,42,44,45,48,49,50';}
       if(rr==2 && cc==2){return '<strong>Temperatura (C) y Altura Geopotencial (m) en 500 hPa</strong><br><br><strong>20260619 a 12</strong> UTC HH+096 (rango:084-108)<br>grupo: <strong>2</strong> representante: <strong>29</strong> miembros: 25 <br>1,3,4,5,6,8,10,11,12,13,16,17,19,21,23,26,29,30,31,35,40,41,43,46,47';}
       if(rr==9 && cc==0){return '<strong>Temperatura en 850 hPa (C) y Presion en Superficie (hPa)</strong><br><br><strong>20260619 a 12</strong> UTC HH+096 (rango:084-108)<br><strong>control +<br>EPS</strong>';}
       if(rr==9 && cc==1){return '<strong>Temperatura en 850 hPa (C) y Presion en Superficie (hPa)</strong><br><br><strong>20260619 a 12</strong> UTC HH+096 (rango:084-108)<br>grupo: <strong>1</strong> representante: <strong>18</strong> miembros: 26 <strong>control</strong><br>0,2,7,9,14,15,18,20,22,24,25,27,28,32,33,34,36,37,38,39,42,44,45,48,49,50';}
       if(rr==9 && cc==2){return '<strong>Temperatura en 850 hPa (C) y Presion en Superficie (hPa)</strong><br><br><strong>20260619 a 12</strong> UTC HH+096 (rango:084-108)<br>grupo: <strong>2</strong> representante: <strong>29</strong> miembros: 25 <br>1,3,4,5,6,8,10,11,12,13,16,17,19,21,23,26,29,30,31,35,40,41,43,46,47';}
       if(rr==10 && cc==0){return '<strong>Temperatura en 850 hPa (C) y Presion en Superficie (hPa)</strong><br><br><strong>20260619 a 12</strong> UTC HH+096 (rango:084-108)<br><strong>control +<br>EPS</strong>';}
       if(rr==10 && cc==1){return '<strong>Temperatura en 850 hPa (C) y Presion en Superficie (hPa)</strong><br><br><strong>20260619 a 12</strong> UTC HH+096 (rango:084-108)<br>grupo: <strong>1</strong> representante: <strong>18</strong> miembros: 26 <strong>control</strong><br>0,2,7,9,14,15,18,20,22,24,25,27,28,32,33,34,36,37,38,39,42,44,45,48,49,50';}
       if(rr==10 && cc==2){return '<strong>Temperatura en 850 hPa (C) y Presion en Superficie (hPa)</strong><br><br><strong>20260619 a 12</strong> UTC HH+096 (rango:084-108)<br>grupo: <strong>2</strong> representante: <strong>29</strong> miembros: 25 <br>1,3,4,5,6,8,10,11,12,13,16,17,19,21,23,26,29,30,31,35,40,41,43,46,47';}
       if(rr==11 && cc==0){return '<strong>Temperatura a 2m (C)</strong><br><br><strong>20260619 a 12</strong> UTC HH+096 (rango:084-108)<br><strong>control +<br>EPS</strong>';}
       if(rr==11 && cc==1){return '<strong>Temperatura a 2m (C)</strong><br><br><strong>20260619 a 12</strong> UTC HH+096 (rango:084-108)<br>grupo: <strong>1</strong> representante: <strong>18</strong> miembros: 26 <strong>control</strong><br>0,2,7,9,14,15,18,20,22,24,25,27,28,32,33,34,36,37,38,39,42,44,45,48,49,50';}
       if(rr==11 && cc==2){return '<strong>Temperatura a 2m (C)</strong><br><br><strong>20260619 a 12</strong> UTC HH+096 (rango:084-108)<br>grupo: <strong>2</strong> representante: <strong>29</strong> miembros: 25 <br>1,3,4,5,6,8,10,11,12,13,16,17,19,21,23,26,29,30,31,35,40,41,43,46,47';}
       if(rr==12 && cc==0){return '<strong>Racha maxima de viento a 10m en 6 horas anteriores (nudos)</strong><br><br><strong>20260619 a 12</strong> UTC HH+096 (rango:084-108)<br><strong>control +<br>EPS</strong>';}
       if(rr==12 && cc==1){return '<strong>Racha maxima de viento a 10m en 6 horas anteriores (nudos)</strong><br><br><strong>20260619 a 12</strong> UTC HH+096 (rango:084-108)<br>grupo: <strong>1</strong> representante: <strong>18</strong> miembros: 26 <strong>control</strong><br>0,2,7,9,14,15,18,20,22,24,25,27,28,32,33,34,36,37,38,39,42,44,45,48,49,50';}
       if(rr==12 && cc==2){return '<strong>Racha maxima de viento a 10m en 6 horas anteriores (nudos)</strong><br><br><strong>20260619 a 12</strong> UTC HH+096 (rango:084-108)<br>grupo: <strong>2</strong> representante: <strong>29</strong> miembros: 25 <br>1,3,4,5,6,8,10,11,12,13,16,17,19,21,23,26,29,30,31,35,40,41,43,46,47';}
       if(rr==13 && cc==0){return '<strong>MUCAPE (J/Kg)</strong><br><br><strong>20260619 a 12</strong> UTC HH+096 (rango:084-108)<br><strong>control +<br>EPS</strong>';}
       if(rr==13 && cc==1){return '<strong>MUCAPE (J/Kg)</strong><br><br><strong>20260619 a 12</strong> UTC HH+096 (rango:084-108)<br>grupo: <strong>1</strong> representante: <strong>18</strong> miembros: 26 <strong>control</strong><br>0,2,7,9,14,15,18,20,22,24,25,27,28,32,33,34,36,37,38,39,42,44,45,48,49,50';}
       if(rr==13 && cc==2){return '<strong>MUCAPE (J/Kg)</strong><br><br><strong>20260619 a 12</strong> UTC HH+096 (rango:084-108)<br>grupo: <strong>2</strong> representante: <strong>29</strong> miembros: 25 <br>1,3,4,5,6,8,10,11,12,13,16,17,19,21,23,26,29,30,31,35,40,41,43,46,47';}
       if(rr==14 && cc==0){return '<strong>Precipitacion de 00 a 24 UTC (mm)</strong><br><br><strong>20260619 a 12</strong> UTC HH+096 (rango:084-108)<br><strong>control +<br>EPS</strong>';}
       if(rr==14 && cc==1){return '<strong>Precipitacion de 00 a 24 UTC (mm)</strong><br><br><strong>20260619 a 12</strong> UTC HH+096 (rango:084-108)<br>grupo: <strong>1</strong> representante: <strong>18</strong> miembros: 26 <strong>control</strong><br>0,2,7,9,14,15,18,20,22,24,25,27,28,32,33,34,36,37,38,39,42,44,45,48,49,50';}
       if(rr==14 && cc==2){return '<strong>Precipitacion de 00 a 24 UTC (mm)</strong><br><br><strong>20260619 a 12</strong> UTC HH+096 (rango:084-108)<br>grupo: <strong>2</strong> representante: <strong>29</strong> miembros: 25 <br>1,3,4,5,6,8,10,11,12,13,16,17,19,21,23,26,29,30,31,35,40,41,43,46,47';}
       if(rr==15 && cc==0){return '<strong>Nieve acumulada de 00 a 24 UTC (mm de agua equivalente)</strong><br><br><strong>20260619 a 12</strong> UTC HH+096 (rango:084-108)<br><strong>control +<br>EPS</strong>';}
       if(rr==15 && cc==1){return '<strong>Nieve acumulada de 00 a 24 UTC (mm de agua equivalente)</strong><br><br><strong>20260619 a 12</strong> UTC HH+096 (rango:084-108)<br>grupo: <strong>1</strong> representante: <strong>18</strong> miembros: 26 <strong>control</strong><br>0,2,7,9,14,15,18,20,22,24,25,27,28,32,33,34,36,37,38,39,42,44,45,48,49,50';}
       if(rr==15 && cc==2){return '<strong>Nieve acumulada de 00 a 24 UTC (mm de agua equivalente)</strong><br><br><strong>20260619 a 12</strong> UTC HH+096 (rango:084-108)<br>grupo: <strong>2</strong> representante: <strong>29</strong> miembros: 25 <br>1,3,4,5,6,8,10,11,12,13,16,17,19,21,23,26,29,30,31,35,40,41,43,46,47';}
       if(rr==16 && cc==0){return '<strong>Viento a 10 m (m/s)</strong><br><br><strong>20260619 a 12</strong> UTC HH+096 (rango:084-108)<br><strong>control +<br>EPS</strong>';}
       if(rr==16 && cc==1){return '<strong>Viento a 10 m (m/s)</strong><br><br><strong>20260619 a 12</strong> UTC HH+096 (rango:084-108)<br>grupo: <strong>1</strong> representante: <strong>18</strong> miembros: 26 <strong>control</strong><br>0,2,7,9,14,15,18,20,22,24,25,27,28,32,33,34,36,37,38,39,42,44,45,48,49,50';}
       if(rr==16 && cc==2){return '<strong>Viento a 10 m (m/s)</strong><br><br><strong>20260619 a 12</strong> UTC HH+096 (rango:084-108)<br>grupo: <strong>2</strong> representante: <strong>29</strong> miembros: 25 <br>1,3,4,5,6,8,10,11,12,13,16,17,19,21,23,26,29,30,31,35,40,41,43,46,47';}
}
